Learn R Programming

Rvision (version 0.2.2)

medianBlur: Blurs an Image Using a Median Filter

Description

medianBlur smoothes an image using a median filter, i.e. the value of each pixel is replaced by the median value of all the pixels in its neighborhood.

Usage

medianBlur(image, k_size)

Arguments

image

An Image object.

k_size

The half-size in pixels of the kernel.

Value

image An Image object.

See Also

Image, gaussianBlur

Examples

Run this code
# NOT RUN {
# TODO
# }

Run the code above in your browser using DataLab